@@ -24,6 +24,10 @@ has 'elseBranch' => (
   );
 
 
+override parse ( Int $index, ArrayRef[Str] $input,  ArrayRef[TSQL::AST::SQLFragment] $output ) {
+    return ;
+}
+
 }
 
 
