@@ -16,6 +16,10 @@ has 'catchBlock' => (
   );
 
 
+override parse ( Int $index, ArrayRef[Str] $input,  ArrayRef[TSQL::AST::SQLFragment] $output ) {
+    return ;
+}
+
 }
 
 
